# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`exim`](#exim): This module configures exim

_Private Classes_

* `exim::config`: 
* `exim::install`: This class installes the exim package
* `exim::service`: This class manages the exim service

**Defined types**

* [`exim::acl`](#eximacl): This define creates a new acl
* [`exim::acl::statement`](#eximaclstatement): This define creates one acl statement in exims configuration
* [`exim::addresslist`](#eximaddresslist): 
* [`exim::authenticator`](#eximauthenticator): This module configures a single authenticator in exims configuration
* [`exim::domainlist`](#eximdomainlist): This define can be used to create domainlists, which can be referenced later
* [`exim::hostlist`](#eximhostlist): This define can be used to create hostlists, which can be referenced later
* [`exim::retry`](#eximretry): This define is used to build retry rules
* [`exim::rewrite`](#eximrewrite): This define is used to build rewrite rules
* [`exim::router`](#eximrouter): This module configures a single router in exims configuration
* [`exim::transport`](#eximtransport): This module configures a single transport in exims configuration

## Classes

### exim

This module configures exim

#### Examples

##### 

```puppet
include ::exim
```

#### Parameters

The following parameters are available in the `exim` class.

##### `acl_not_smtp`

Data type: `Optional[String]`

Name of acl used for local generated mail. (sendmail)

##### `acl_smtp_auth`

Data type: `Optional[String]`

Name of acl used for auth checking
Type: string

##### `acl_smtp_data`

Data type: `Optional[String]`

Name of acl used for data checking
  (runs after SMTP "." command)
Type: string

##### `acl_smtp_mail`

Data type: `Optional[String]`

Name of acl used for mail checking
  (runs after SMTP "MAIL FROM:" command)
Type: string

##### `acl_smtp_mime`

Data type: `Optional[String]`

Name of acl used for maime checking
Type: string

##### `acl_smtp_rcpt`

Data type: `Any`

Name of acl used for rcpt checking.
  (runs after SMTP "RCPT TO:" command)
Type: string

##### `allow_mx_to_ip`

Data type: `Any`

Using an ip instead of an fqdn in DNS MX records violates the RFC,
this option allows sending mails to these domains anyways.
Type: bool

##### `auto_thaw`

Data type: `Optional[String]`

Thaw frozen mails in our mailq after this time
Type: string
Example: "5d"

##### `av_scanner`

Data type: `Optional[String]`

Configure your av-scanner here
Type: string
Example: "clamd:/var/run/clamav/clamd.ctl"

##### `callout_domain_positive_expire`

Data type: `Optional[String]`

SMTP callouts are cached, this options sets the time after a successfull
callout is deleted from the cache.
Type: string
Example: "4h"

##### `check_spool_space`

Data type: `Optional[String]`

Don't accept mails, if spool space falls below this watermark.
Type: string
Example: 1G

##### `chunking_advertise_hosts`

Data type: `Optional[Array[String]]`

advertise CHUNKING to these hosts
Type: array
Example: ['10.0.0.1', '192.168.178.1']

##### `queue_smtp_domains`

Data type: `Optional[Array[String]]`

no immediaste SMTP delivery for these domains
Type: array
Example: ['10.0.0.1', '192.168.178.1']

##### `config_path`

Data type: `Any`

Path to exims config file, this can be used to create an alternate config file
for testing purposes.
Type: string
Example: "/etc/exim4/exim4.conf_test"

##### `daemon_smtp_ports`

Data type: `Optional[Array[Integer]]`

SMTP ports to listen on
Type: array
Example: ['25','587']

##### `defaults`

Data type: `Any`

Use a default configuration, this creates a simple default config,
which accepts local mails and forwards it to mail.<domain of your server>
You probably want to set this to false, and build your own config.
Type: bool
Default: true

##### `delay_warning`

Data type: `Optional[Array[String]]`

Send a warning Mail to the sender, if mails are delayed for this long:
Type: Array
Example: ['4h','8h','24h']

##### `deliver_queue_load_max`

Data type: `Optional[Integer]`

Stop running the queue if load is higher than this value
Type: integer

##### `disable_ipv6`

Data type: `Optional[Boolean]`

Do no IPv6 processing
Type: bool

##### `errors_reply_to`

Data type: `Optional[String]`

This sets a mail-address to be used in the reply-to header of bounce-messages.
Type: String
Example: postmaster@example.com

##### `extract_addresses_remove_arguments`

Data type: `Optional[Boolean]`

When using exims -t option, rcpts from the Mail-Headers are used, and rcpts given
on the command-line are substracted, setting this to false will add the rcpts instead
of substracting them

##### `freeze_tell`

Data type: `Optional[String]`

If a mail gets frozen, send a notification to the address defined here.

##### `gnutls_compat_mode`

Data type: `Optional[Boolean]`

This controls if gnutls is used in compatiblity mode.
Set this to true to slightly reduce security, but improve compatiblity with older
TLS implementations.
Type: bool

##### `openssl_options`

Data type: `Optional[String]`

Adjust OpenSSL compatibility options.
Type: String

##### `heavy`

Data type: `Optional[Boolean]`

Install the debian heavy variant, default is false
does nothing for redhat

##### `helo_allow_chars`

Data type: `Optional[String]`

Allow additional characters in remote HELO strings.
Type: string

##### `host_lookup`

Data type: `Any`

Reverse lookup hostname of ips.
Type: Array
Example: '*'

##### `hosts_treat_as_local`

Data type: `Optional[Array[String]]`

Treat these hosts, as if they where the local host.
default is empty

##### `ignore_bounce_errors_after`

Data type: `Any`

Discard undeliverable bounce messages after this time
Type String:
Example: "12d"

##### `includes`

Data type: `Any`

Include additional config file snippets, files defined here will be included at
the top of the configuration, but below macros.

##### `local_from_check`

Data type: `Any`

Check and correct From: header from local mails to username@qualify-domain

##### `local_interfaces`

Data type: `Optional[Array[String]]`

Specifies the interfaces exim will listen on.

##### `log_file_path`

Data type: `Optional[Array[String]]`

Type: string

##### `log_lost_incoming_connection`

Data type: `Optional[Boolean]`

Configures the log_selector to log timeouting incomming connections

##### `log_retry_defer`

Data type: `Optional[Boolean]`

Configures the log_selector to log if the queue runner skips a mail
because it's retry time is not yet reached.

##### `log_sender_on_delivery`

Data type: `Optional[Boolean]`

add sender to => lines

##### `log_skip_delivery`

Data type: `Optional[Boolean]`

delivery skipped in a queue run

##### `log_smtp_confirmation`

Data type: `Optional[Boolean]`

SMTP confirmation on => lines

##### `log_smtp_connection`

Data type: `Optional[Boolean]`

Log SMTP connections.

##### `log_smtp_protocol_error`

Data type: `Optional[Boolean]`

Log SMTP protocol errors.

##### `log_smtp_syntax_error`

Data type: `Optional[Boolean]`

Log SMTP syntax errors.

##### `log_tls_peerdn`

Data type: `Optional[Boolean]`

TLS peer DN on <= and => lines

##### `log_mail_subject`

Data type: `Optional[Boolean]`

Log mail subjects.

##### `log_8bitmime`

Data type: `Optional[Boolean]`

received 8BITMIME status

##### `log_acl_warn_skipped`

Data type: `Optional[Boolean]`

skipped warn statement in ACL

##### `log_address_rewrite`

Data type: `Optional[Boolean]`

address rewriting

##### `log_all_parents`

Data type: `Optional[Boolean]`

all parents in => lines

##### `log_arguments`

Data type: `Optional[Boolean]`

command line arguments

##### `log_connection_reject`

Data type: `Optional[Boolean]`

connection rejections

##### `log_delay_delivery`

Data type: `Optional[Boolean]`

immediate delivery delayed

##### `log_deliver_time`

Data type: `Optional[Boolean]`

time taken to perform delivery

##### `log_delivery_size`

Data type: `Optional[Boolean]`

add S=nnn to => lines

##### `log_dnslist_defer`

Data type: `Optional[Boolean]`

defers of DNS list (aka RBL) lookups

##### `log_dnssec`

Data type: `Optional[Boolean]`

DNSSEC secured lookups

##### `log_etrn`

Data type: `Optional[Boolean]`

ETRN commands

##### `log_host_lookup_failed`

Data type: `Optional[Boolean]`

Log failed host lookup

##### `log_ident_timeout`

Data type: `Optional[Boolean]`

timeout for ident connection

##### `log_incoming_interface`

Data type: `Optional[Boolean]`

local interface on <= and => lines

##### `log_incoming_port`

Data type: `Optional[Boolean]`

remote port on <= lines

##### `log_millisec`

Data type: `Optional[Boolean]`

millisecond timestamps and QT,DT,D times

##### `log_outgoing_interface`

Data type: `Optional[Boolean]`

local interface on => lines

##### `log_outgoing_port`

Data type: `Optional[Boolean]`

add remote port to => lines

##### `log_queue_run`

Data type: `Optional[Boolean]`

start and end queue runs

##### `log_queue_time`

Data type: `Optional[Boolean]`

time on queue for one recipient

##### `log_queue_time_overall`

Data type: `Optional[Boolean]`

time on queue for whole message

##### `log_pid`

Data type: `Optional[Boolean]`

Exim process id

##### `log_proxy`

Data type: `Optional[Boolean]`

proxy address on <= and => lines

##### `log_received_recipients`

Data type: `Optional[Boolean]`

recipients on <= lines

##### `log_received_sender`

Data type: `Optional[Boolean]`

sender on <= lines

##### `log_rejected_header`

Data type: `Optional[Boolean]`

header contents on reject log

##### `log_return_path_on_delivery`

Data type: `Optional[Boolean]`

put return path on => and ** lines

##### `log_sender_verify_fail`

Data type: `Optional[Boolean]`

sender verification failures

##### `log_size_reject`

Data type: `Optional[Boolean]`

rejection because too big

##### `log_smtp_incomplete_transaction`

Data type: `Optional[Boolean]`

incomplete SMTP transactions

##### `log_smtp_mailauth`

Data type: `Optional[Boolean]`

AUTH argument to MAIL commands

##### `log_smtp_no_mail`

Data type: `Optional[Boolean]`

session with no MAIL commands

##### `log_tls_certificate_verified`

Data type: `Optional[Boolean]`

certificate verification status

##### `log_tls_cipher`

Data type: `Optional[Boolean]`

TLS cipher suite on <= and => lines

##### `log_tls_sni`

Data type: `Optional[Boolean]`

TLS SNI on <= lines

##### `log_unknown_in_list`

Data type: `Optional[Boolean]`

DNS lookup failed in list match

##### `log_timezone`

Data type: `Optional[Boolean]`

Timezone

##### `log_file_path`

File path

##### `macros`

Data type: `Optional[Hash]`

Allows you to set Macro definitions, note that macros must
start with an uppercase letter

##### `manage_service`

Data type: `Boolean`

Manage exim Service

##### `message_logs`

Data type: `Optional[Boolean]`

This stores an aditional log file with each message in the spool file
which enables you to instantly get all logs from a message in your
queue by using the exim -Mvl option.

##### `message_size_limit`

Data type: `Optional[String]`

Max size allowed for mails, default is empty
Example: 100M

##### `never_users`

Data type: `Optional[Array[String]]`

Do not run deliverys as these users
Type: array

##### `qualify_domain`

Data type: `Optional[String]`

configure the domain, which is automatically added to email addresses
without a domain part. Default is empty, which exim treats as the
primary hostname.

##### `queue_only_load`

Data type: `Optional[Integer]`

Do not run imediate deliveries if load is above this threshhold.
Type: integer

##### `queue_run_max`

Data type: `Optional[Integer]`

Limits the number of queue runners to run in parrallel.
Type: integer

##### `remote_max_parallel`

Data type: `Optional[Integer]`

If one message with multiple recipients is delivered, run at max these
deliveries in parallel.

##### `rfc1413_hosts`

Data type: `Any`

use identd callback on these hosts.
Type: array

##### `rfc1413_query_timeout`

Data type: `Any`

Timeout for identd callback

##### `smtp_accept_max`

Data type: `Optional[Integer]`

Limit on incomming connections
Type: integer

##### `smtp_accept_max_nonmail`

Data type: `Optional[Integer]`

Limit the amount of non-mail commands in smtp dialog
Type: integer

##### `smtp_accept_max_per_connection`

Data type: `Optional[Integer]`

Maximum number of Mails accepted in a single connection.

##### `smtp_accept_max_per_host`

Data type: `Optional[Integer]`

Maximum number of parrallel connections from a single host

##### `smtp_accept_queue`

Data type: `Optional[Integer]`

If the number of simultaneous incoming SMTP connections being handled via the
listening daemon exceeds this value, messages received by SMTP are just
placed on the queue.

##### `smtp_accept_queue_per_connection`

Data type: `Optional[Integer]`

Maximum number of delivery processes spawned for a single smtp connection

##### `smtp_accept_reserve`

Data type: `Optional[Integer]`

When smtp_accept_max is set greater than zero, this option specifies a number
of SMTP connections that are reserved for connections from the hosts that
are specified in smtp_reserve_hosts.

##### `smtp_banner`

Data type: `Optional[String]`

Initial response to SMTP connections.

##### `smtp_reserve_hosts`

Data type: `Optional[Array[String]]`

See "smtp_accept_reserve"

##### `spamd_address`

Data type: `Optional[String]`

Configure a spamd socket here.

##### `split_spool_directory`

Data type: `Optional[Boolean]`

Use split spool configuration
Type: bool

##### `syslog_timestamp`

Data type: `Optional[Boolean]`

Don't send timestamps to syslog.

##### `system_filter`

Data type: `Optional[String]`

Configure a system filter file here.

##### `timeout_frozen_after`

Data type: `Optional[String]`

Discard frozen mails after this amount of time.

##### `tls_advertise_hosts`

Data type: `Optional[Array[String]]`

Advertise tls to hosts in this list

##### `tls_certificate`

Data type: `Optional[String]`

Path to crt file, must be used together with tls_privatekey, default is empty (no tls)

##### `tls_privatekey`

Data type: `Optional[String]`

Path to key file, must be used together with tls_certificate, default is empty (no tls)

##### `trusted_users`

Data type: `Optional[Array[String]]`

Set, to configure exims global config variable trusted_users,
default is empty ('').

##### `print_topbitchars`

Data type: `Optional[Boolean]`

If this option ist set to true code values of 128 and above are also considered to be printing characters

##### `untrusted_set_sender`

Data type: `Optional[Boolean]`

This option allows you to permit untrusted users to set other envelope sender addresses in a controlled way.

##### `tls_require_ciphers`

Data type: `Optional[String]`

This option controls which ciphers can be used for incoming TLS connections.

##### `ldap_default_servers`

Data type: `Optional[Array[String]]`

Array of LDAP servers (fqdn)

##### `exim_heavy_package`

Data type: `Optional[String]`

Name of the Debian exim-heavy package

##### `exim_light_package`

Data type: `Optional[String]`

Name of the Debian exim-light package

##### `exim_service`

Data type: `Optional[String]`

Name of the service

## Defined types

### exim::acl

This define creates a new acl

* **See also**
http://www.exim.org/exim-html-current/doc/html/spec_html/ch-access_control_lists.html

#### Parameters

The following parameters are available in the `exim::acl` defined type.

##### `acl_id`

Data type: `Any`

Id of this acl, this is needed for acl statements to reference
this acl.

Default value: `undef`

##### `statements`

Data type: `Any`



Default value: `undef`

### exim::acl::statement

This define creates one acl statement in exims configuration

* **See also**
http://www.exim.org/exim-html-current/doc/html/spec_html/ch-access_control_lists.html

#### Parameters

The following parameters are available in the `exim::acl::statement` defined type.

##### `acl_id`

Data type: `Any`

Id of parent acl this statement correspondes to.
The acl-statement is part of the acl with id "acl_id".

##### `order`

Data type: `Any`

Position of this statement in the acl (acl_id).

##### `action`

Data type: `Any`

The outcome of given acl statement (e.g.: accept)

##### `conditions`

Data type: `Any`

Conditions to "action"
Example:
  [
    ['hosts',   ['192.168.1.2','192.168.1.3']],
    ['domains', ['+domainlist']],
  ],

Default value: `undef`

##### `disable`

Data type: `Boolean`

This option can be used to ignore this acl statement
even if other options are set.
This is usefull if statements are created via
hiera_hash with deep_merge, and you want to
completly disable a statement defined in a lower
hierachy.

Default value: `false`

### exim::addresslist

The exim::addresslist class.

#### Parameters

The following parameters are available in the `exim::addresslist` defined type.

##### `addresses`

Data type: `Any`



Default value: `undef`

### exim::authenticator

This module configures a single authenticator in exims configuration

#### Parameters

The following parameters are available in the `exim::authenticator` defined type.

##### `client_name`

Data type: `Any`

This string is expanded, and the result used as the user name data
when computing the response to the server’s challenge.

Default value: `undef`

##### `client_secret`

Data type: `Any`

This option must be set for the authenticator to work as a client.
Its value is expanded and the result used as the secret string when
computing the response.

Default value: `undef`

##### `client_send`

Data type: `Any`

Array of authentication data strings. The first string is send with
the AUTH command. The remaining ones are send in response to prompts
from the server. Circumflex characters ('^') are converted to binary
zero bytes ('\0') by Exim.

Default value: `undef`

##### `driver`

Data type: `Any`

driver to use for the authenticator

##### `public_name`

Data type: `Any`

How to anounce the authenticator to the outside (PLAIN/LOGIN)

##### `server_secret`

Data type: `Any`

For use with cram_md5, server_secret is expanded
to obtain the password for that user.

Default value: `undef`

##### `server_condition`

Data type: `Any`

The authentication check

Default value: `undef`

##### `server_set_id`

Data type: `Any`

Set the $authenticated_id variable for later use

Default value: `undef`

##### `server_prompts`

Data type: `Any`

Promt used in the smtp session to ask for data  (User: Password:)

Default value: `undef`

### exim::domainlist

This define can be used to create domainlists, which can be referenced later

* **See also**
http://www.exim.org/exim-html-current/doc/html/spec_html/ch-domain_host_address_and_local_part_lists.html

#### Parameters

The following parameters are available in the `exim::domainlist` defined type.

##### `domains`

Data type: `Any`

Array containing a list of domains

Default value: `undef`

##### `path`

Data type: `Any`

If path is set, domains are listed in a file located in this path, the main config will recieve
a reference to this file.
If path is not set, domains are written directly into the config file instead.

Default value: `undef`

### exim::hostlist

This define can be used to create hostlists, which can be referenced later

* **See also**
http://www.exim.org/exim-html-current/doc/html/spec_html/ch-domain_host_address_and_local_part_lists.html

#### Parameters

The following parameters are available in the `exim::hostlist` defined type.

##### `hosts`

Data type: `Any`

Array containing a list of hosts

Default value: `undef`

### exim::retry

This define is used to build retry rules

#### Parameters

The following parameters are available in the `exim::retry` defined type.

##### `order`

Data type: `Any`

Determines the order, in which retry statements are evaluated

Default value: 1

##### `error`

Data type: `Any`

Determines on which errors the rule should apply

Default value: '*'

##### `retries`

Data type: `Any`

Timing information for retries
Type: hash of hashes

Default value: [['F','4h','5m'],['G','16h','1h','1.5'],['F','4d','6h']]

##### `domain`

Data type: `Any`



Default value: $title

### exim::rewrite

This define is used to build rewrite rules

#### Parameters

The following parameters are available in the `exim::rewrite` defined type.

##### `order`

Data type: `Integer`

Determines the order, in which retry statements are evaluated

Default value: 1

##### `pattern`

Data type: `String`

Matches those addresses that are to be rewriten by rule

##### `replacement`

Data type: `String`

the replacement string for matching pattern

##### `flags`

Data type: `Array[Enum['E','F','T','b','c','f','h','r','s','t','Q','q','R','w','S']]`

The flags are single characters which indicates the address location
to which the rule applies and how the rewriting takes place

### exim::router

override the destination of a generated bounce message

specify a text message which is used when an address can not be routed because of no more routers to try. Default
message is "Unroutable address"

dont run this router if specified files does not exist

#### Parameters

The following parameters are available in the `exim::router` defined type.

##### `disable`

Data type: `Boolean`

If set to true, this router is excluded from the configuration.

Default value: `false`

##### `order`

Data type: `Any`

Order of routers is important, set it here

##### `address_data`

Data type: `Any`

Set the address_data variable

Default value: `undef`

##### `caseful_local_part`

Data type: `Any`

Sets the caseful_local_part option.

Default value: `undef`

##### `comment`

Data type: `Any`

Comment a router, this will be placed as a comment just above
the router.

Default value: `undef`

##### `driver`

Data type: `Any`

Sets the type of router.

##### `allow_defer`

Data type: `Boolean`

If set to true, the router can defer messages if needed.

Default value: `false`

##### `allow_fail`

Data type: `Boolean`

If set to true, the router can fail messages if needed.

Default value: `false`

##### `allow_filter`

Data type: `Boolean`

If set to true, filters can be used.

Default value: `false`

##### `condition`

Data type: `Any`

(Advanced) Conditions when this router should be used

Default value: `undef`

##### `data`

Data type: `Any`

Data source for the rewrite router

Default value: `undef`

##### `debug_print`

Data type: `Any`

Used to print debug information

Default value: `undef`

##### `domains`

Data type: `Any`

Domains for which this router should be used.

Default value: `undef`

##### `file_transport`

Data type: `Any`

Set the file_transport, used if the outcome of the router points to a file

Default value: `undef`

##### `file`

Data type: `Any`

Set the file that contains the filter rules.

Default value: `undef`

##### `headers_add`

Data type: `Any`

Add these Headers to a message

Default value: `undef`

##### `headers_remove`

Data type: `Any`

Remove these Headers to a message

Default value: `undef`

##### `host_find_failed`

Data type: `Any`

Relevant to the manualroute router, it determines what shoud
happen if the used host can't be resolved to an IP address.

Default value: `undef`

##### `ignore_target_hosts`

Data type: `Any`

remove this host from hostlists gererated by this router

Default value: `undef`

##### `local_parts`

Data type: `Any`

The router is run only if the local part of the address matches the list.

Default value: `undef`

##### `local_part_prefix`

Data type: `Any`

Define a prefix, present on localparts

Default value: `undef`

##### `local_part_suffix`

Data type: `Any`

Define a suffix, present on localparts

Default value: `undef`

##### `local_part_prefix_optional`

Data type: `Boolean`

Is the prefix optional?

Default value: `false`

##### `local_part_suffix_optional`

Data type: `Boolean`

Is the suffix optional?

Default value: `false`

##### `no_address_test`

Data type: `Boolean`

Skip this router in address testing mode (exim -bt)

Default value: `false`

##### `no_more`

Data type: `Boolean`

If conditions are met for this router, but the router can't process
this mail, the address fails instead of handeld down to the next router.

Default value: `false`

##### `no_verify`

Data type: `Boolean`

Skip this router when verifying addresses.

Default value: `false`

##### `pipe_transport`

Data type: `Any`

Set the pipe_transport, used if the outcome of the router points to a pipe

Default value: `undef`

##### `qualify_preserve_domain`

Data type: `Boolean`

For redirect routers
If an unqualified address (one without a domain) is generated, it is qualified with the domain of the parent address.

Default value: `false`

##### `route_data`

Data type: `Any`

If this option is set, it must expand to yield the data part of a routing rule.

Default value: `undef`

##### `route_list`

Data type: `Any`

Target server used by manualroute router.

Default value: `undef`

##### `same_domain_copy_routing`

Data type: `Any`

This option copys routing information to all mails targeting the same domain.

Default value: `undef`

##### `self`

Data type: `Any`

The self option specifies what happens when the first host on the list turns out to be the local host.
See official documentation for more details.

Default value: `undef`

##### `senders`

Data type: `Any`

If this option is set, the router is skipped unless the message’s sender address matches something on the list.

Default value: `undef`

##### `transport`

Data type: `Any`

Which transport should be used to send mails.

Default value: `undef`

##### `unseen`

Data type: `Boolean`

When this option is set true, routing does not cease if the router accepts the address.

Default value: `false`

##### `user`

Data type: `Any`

When a router queues an address for a transport, and the transport does not specify a user,
the user given here is used when running the delivery process.

Default value: `undef`

##### `errors_to`

Data type: `Any`



Default value: `undef`

##### `cannot_route_message`

Data type: `Any`



Default value: `undef`

##### `require_files`

Data type: `Any`



Default value: `undef`

### exim::transport

This module configures a single transport in exims configuration

#### Parameters

The following parameters are available in the `exim::transport` defined type.

##### `allow_localhost`

Data type: `Boolean`

Allow connections to localhost

Default value: `false`

##### `comment`

Data type: `Any`

Comment a router, this will be placed as a comment just above
the router.

Default value: `undef`

##### `driver`

Data type: `Any`

Type of transport.

##### `protocol`

Data type: `Any`

Protocol of transport.

Default value: `undef`

##### `connect_timeout`

Data type: `Any`

Timeout when connecting to remote Servers.

Default value: `undef`

##### `connection_max_messages`

Data type: `Any`

Set the maximum number of messages that can be transfered in a single connection.

Default value: `undef`

##### `exim_environment`

Data type: `Any`

This option is used to add additional variables to the environment in which the command runs.

Default value: `undef`

##### `fallback_hosts`

Data type: `Any`

If Exim is unable to deliver to any of the hosts for a particular address, and the
errors are not permanent rejections, the address is put on a separate transport
queue with its host list replaced by the fallback hosts.

Default value: `undef`

##### `from`

Data type: `Any`

sets the from address

Default value: `undef`

##### `helo_data`

Data type: `Any`

sets the helo name exim uses when connecting to a remote server.

Default value: `undef`

##### `headers_remove`

Data type: `Any`

list of headers to remove.

Default value: `undef`

##### `headers_add`

Data type: `Any`

list of headers to add.

Default value: `undef`

##### `hosts`

Data type: `Any`

The hosts option specifies a list of hosts to be used if the address
being processed does not have any hosts associated with it. The hosts
specified by hosts are also used, whether or not the address has its
own hosts, if hosts_override is set.

Default value: `undef`

##### `hosts_require_auth`

Data type: `Any`

Specifies a list of servers for which authentication must succeed before Exim will try
to transfer a message. If authentication fails for one of these servers, delivery is deferred.

Default value: `undef`

##### `hosts_require_tls`

Data type: `Any`

List of hosts requiring tls, messages are only sent if tls can be established.

Default value: `undef`

##### `hosts_try_auth`

Data type: `Any`

The host_try_auth option provides a list of hosts to which, provided they announce
authentication support, Exim will attempt to authenticate as a client when it connects.

Default value: `undef`

##### `path`

Data type: `Any`

This option specifies the string that is set up in the
PATH environment variable of the subprocess.

Default value: `undef`

##### `port`

Data type: `Any`

The port exim connects to on the remote server

Default value: `undef`

##### `return_fail_output`

Data type: `Boolean`

If set to true, the command output is returned in the bounce message in case of failure.

Default value: `false`

##### `return_output`

Data type: `Boolean`

If this option is true, and the command produced any output, the delivery
is deemed to have failed whatever the return code from the command, and
the output is returned in the bounce message

Default value: `false`

##### `timeout`

Data type: `Any`

If the command fails to complete within this time, it is killed.

Default value: `undef`

##### `timeout_defer`

Data type: `Boolean`

Set this to true for timeouts to become temporary errors, causing the
delivery to be deferred.

Default value: `false`

##### `tls_dh_min_bits`

Data type: `Any`

set the minimum acceptable number of bits in the Diffie-Hellman prime
offered by a server,
default is 1024

Default value: `undef`

##### `tls_verify_certificates`

Data type: `Any`

Give a path to certificates agains which connections are verified.

Default value: `undef`

##### `interface`

Data type: `Any`

sets the outgoing ip for smtp transports.

Default value: `undef`

##### `dkim_domain`

Data type: `Any`

The domain(s) you want to sign with

Default value: `undef`

##### `dkim_selector`

Data type: `Any`

This sets the key selector string.

Default value: `undef`

##### `dkim_private_key`

Data type: `Any`

This sets the private key to use. You can use the $dkim_domain and
$dkim_selector expansion variables to determine the private key to use.
The result can either
 - be a valid RSA private key in ASCII armor, including line breaks.
 - start with a slash, in which case it is treated as a file that contains
   the private key.
 - be "0", "false" or the empty string, in which case the message will not
   be signed. This case will not result in an error, even if dkim_strict
   is set.

Default value: `undef`

##### `dkim_canon`

Data type: `Any`

This option sets the canonicalization method used when signing a message.
The DKIM RFC currently supports two methods: "simple" and "relaxed".
Note: the current implementation only supports using the same
canonicalization method for both headers and body.

Default value: `undef`

##### `dkim_strict`

Data type: `Any`

This option defines how Exim behaves when signing a message that should be
signed fails for some reason.
When the expansion evaluates to either "1" or "true", Exim will defer.
Otherwise Exim will send the message unsigned.
You can use the $dkim_domain and $dkim_selector expansion variables here.

Default value: `undef`

##### `once`

Data type: `Any`

Use:autoreply;Type:string;Default:unset; This option names a file or DBM
database in which a record of each To: recipient is kept when the message
is specified by the transport.

Default value: `undef`

##### `once_repeat`

Data type: `Any`

Use:autoreply;Type:time;Default:0s; specifies a maximum time between
repeats

Default value: `undef`

##### `once_file_size`

Data type: `Any`

Use:autoreply;Type:integer;Default:0; If once_file_size is zero, a DBM
database is used to remember recipients, and it is allowed to grow as large
as necessary. If once_file_size is set greater than zero, it changes the
way Exim implements the once option. Instead of using a DBM file to record
every recipient it sends to, it uses a regular file, whose size will never
get larger than the given value.

Default value: `undef`

##### `headers`

Data type: `Any`

Use:autoreply;Type:string;Default:unset; This specifies additional RFC 2822
headers that are to be added to the message when the message is specified
by the transport. Several can be given by using “\n” to separate them.
There is no check on the format.

Default value: `undef`

##### `return_message`

Data type: `Any`

Use:autoreply;Type:boolean;Default:false; If this is set, a copy of the
original message is returned with the new message, subject to the maximum
size set in the return_size_limit global configuration option.

Default value: `undef`

##### `debug_print`

Data type: `Any`

Used to print debug information

Default value: `undef`

##### `batch_max`

Data type: `Any`



Default value: `undef`

##### `command`

Data type: `Any`



Default value: `undef`

##### `delivery_date_add`

Data type: `Boolean`



Default value: `false`

##### `directory_mode`

Data type: `Any`



Default value: `undef`

##### `directory`

Data type: `Any`



Default value: `undef`

##### `envelope_to_add`

Data type: `Boolean`



Default value: `false`

##### `file`

Data type: `Any`



Default value: `undef`

##### `freeze_exec_fail`

Data type: `Boolean`



Default value: `false`

##### `group`

Data type: `Any`



Default value: `undef`

##### `home_directory`

Data type: `Any`



Default value: `undef`

##### `initgroups`

Data type: `Boolean`



Default value: `false`

##### `log_output`

Data type: `Boolean`



Default value: `false`

##### `maildir_format`

Data type: `Boolean`



Default value: `false`

##### `maildir_tag`

Data type: `Any`



Default value: `undef`

##### `message_prefix`

Data type: `Any`



Default value: `undef`

##### `message_suffix`

Data type: `Any`



Default value: `undef`

##### `mode`

Data type: `Any`



Default value: `undef`

##### `rcpt_include_affixes`

Data type: `Boolean`



Default value: `false`

##### `return_path_add`

Data type: `Boolean`



Default value: `false`

##### `socket`

Data type: `Any`



Default value: `undef`

##### `subject`

Data type: `Any`



Default value: `undef`

##### `temp_errors`

Data type: `Any`



Default value: `undef`

##### `text`

Data type: `Any`



Default value: `undef`

##### `to`

Data type: `Any`



Default value: `undef`

##### `transport_filter`

Data type: `Any`



Default value: `undef`

##### `user`

Data type: `Any`



Default value: `undef`

